create table bgp_src (
 id int NOT NULL auto_increment,
 loggerip varchar(12) null,
 peerip varchar(12),
 peeras int unsigned,
 flags bigint unsigned not null default 0,
 PRIMARY KEY  (id)
) engine=innodb;
create table bgp_commonlog (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 msgcode int null,
 msgtxt text null
) engine=MyISAM;

create table bgp_ipv4 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - ipv4u_nlri ; 2 - ipv4u_withdraw
 kind tinyint unsigned not null default 0,
 netaddr int unsigned not null default 0, -- network address
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthop int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 primary key (srcid,kind,netaddr,netsize)
) engine=InnoDB;
create index bgp_ipv4_lbl on bgp_ipv4(bgplabels);
create index bgp_ipv4_ec on bgp_ipv4(bgpextcom);
create index bgp_ipv4_cm on bgp_ipv4(bgpcommunities);
create table bgp_ipv4_log_0000 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - ipv4u_nlri ; 2 - ipv4u_withdraw
 kind tinyint unsigned not null default 0,
 netaddr int unsigned not null default 0, -- network address
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthop int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null
) engine=MyISAM;
create index bgp_ipv4_dt on bgp_ipv4_log_0000(dtwhen);
create index bgp_ipv4_net on bgp_ipv4_log_0000(srcid,kind,netaddr,netsize);
create index bgp_ipv4_lbl on bgp_ipv4_log_0000(bgplabels);
create index bgp_ipv4_ec on bgp_ipv4_log_0000(bgpextcom);
create index bgp_ipv4_cm on bgp_ipv4_log_0000(bgpcommunities);

create table bgp_ipv4_log (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - ipv4u_nlri ; 2 - ipv4u_withdraw
 kind tinyint unsigned not null default 0, -- 1 - ipv4u ; 2 - ipv4m ; 4 - ipv4lu
 netaddr int unsigned not null default 0, -- network address
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthop int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 KEY `bgp_ipv4_dt` (`dtwhen`),
 KEY `bgp_ipv4_net` (`srcid`,`kind`,`netaddr`,`netsize`),
 KEY `bgp_ipv4_lbl` (`bgplabels`),
 KEY `bgp_ipv4_ec` (`bgpextcom`),
 KEY `bgp_ipv4_cm` (`bgpcommunities`)
) engine=MRG_MyISAM INSERT_METHOD=LAST UNION=(`bgp_ipv4_log_0000`);

DROP PROCEDURE IF EXISTS wr_ipv4;
DELIMITER //
CREATE PROCEDURE wr_ipv4(IN _srcid INT,IN _state tinyint,IN _kind tinyint unsigned,IN _netaddr int unsigned,IN _netsize tinyint unsigned,IN _bgporigin tinyint unsigned,
 IN _bgpaspath varchar(255),IN _bgpcommunities varchar(255),IN _bgpnexthop int unsigned,IN _bgpmed int unsigned,IN _bgplocalpref int unsigned,
 IN _bgpatomicaggregate int unsigned,IN _bgpaggregatoras int unsigned,IN _bgpagregatorIP int unsigned,IN _bgporiginatorIP int unsigned,IN _bgpextcom varchar(255),
 IN _bgplabels varchar(255)
)
    DETERMINISTIC
    SQL SECURITY DEFINER
BEGIN
 declare state1 tinyint;
 declare bgporigin1 tinyint unsigned;
 declare bgpaspath1 varchar(255);
 declare bgpcommunities1 varchar(255);
 declare bgpnexthop1 int unsigned;
 declare bgpmed1 int unsigned;
 declare bgplocalpref1 int unsigned;
 declare bgpatomicaggregate1 int unsigned;
 declare bgpaggregatoras1 int unsigned;
 declare bgpagregatorIP1 int unsigned;
 declare bgporiginatorIP1 int unsigned;
 declare bgpextcom1 varchar(255);
 declare bgplabels1 varchar(255);
 select state,bgporigin,bgpaspath,bgpcommunities,bgpnexthop,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels
  into state1,bgporigin1,bgpaspath1,bgpcommunities1,bgpnexthop1,bgpmed1,bgplocalpref1,bgpatomicaggregate1,bgpaggregatoras1,bgpagregatorIP1,bgporiginatorIP1,bgpextcom1,bgplabels1
   from bgp_ipv4 where kind=_kind and srcid=_srcid and netaddr=_netaddr and netsize=_netsize;
 if state1=_state and bgporigin1=_bgporigin and coalesce(bgpaspath1,'-')=coalesce(_bgpaspath,'-') and coalesce(bgpcommunities1,'-')=coalesce(_bgpcommunities,'-') and coalesce(bgpnexthop1,0)=coalesce(_bgpnexthop,0) and coalesce(bgpmed1,0)=coalesce(_bgpmed,0) and coalesce(bgplocalpref1,0)=coalesce(_bgplocalpref,0) and coalesce(bgpatomicaggregate1,0)=coalesce(_bgpatomicaggregate,0) and coalesce(bgpaggregatoras1,0)=coalesce(_bgpaggregatoras,0) and coalesce(bgpagregatorIP1,0)=coalesce(_bgpagregatorIP,0) and coalesce(bgporiginatorIP1,0)=coalesce(_bgporiginatorIP,0) and coalesce(bgpextcom1,'-')=coalesce(_bgpextcom,'-') then
  set state1=1;
 else
 replace into bgp_ipv4 (srcid,state,kind,netaddr,netsize,bgporigin,bgpaspath,bgpcommunities,bgpnexthop,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddr,_netsize,_bgporigin,_bgpaspath,_bgpcommunities,_bgpnexthop,_bgpmed,_bgplocalpref,_bgpatomicaggregate,_bgpaggregatoras,_bgpagregatorIP,_bgporiginatorIP,_bgpextcom,_bgplabels);
 insert delayed into bgp_ipv4_log (srcid,state,kind,netaddr,netsize,bgporigin,bgpaspath,bgpcommunities,bgpnexthop,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddr,_netsize,_bgporigin,_bgpaspath,_bgpcommunities,_bgpnexthop,_bgpmed,_bgplocalpref,_bgpatomicaggregate,_bgpaggregatoras,_bgpagregatorIP,_bgporiginatorIP,_bgpextcom,_bgplabels);
 commit;
 end if;
END;
//
DELIMITER ;

create table bgp_vpnv4 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 128 - vpnv4u
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 netaddr int unsigned not null default 0, -- network address
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 nexthoprdh int unsigned null,
 nexthoprdl int unsigned null,
 nexthopip int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 primary key (srcid,kind,netaddrrdh,netaddrrdl,netaddr,netsize)
) engine=InnoDB;
create index bgp_vpnv4_lbl on bgp_vpnv4(bgplabels);
create index bgp_vpnv4_ec on bgp_vpnv4(bgpextcom);
create index bgp_vpnv4_cm on bgp_vpnv4(bgpcommunities);

create table bgp_vpnv4_log_0000 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 128 - vpnv4u
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 netaddr int unsigned not null default 0, -- network address
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 nexthoprdh int unsigned null,
 nexthoprdl int unsigned null,
 nexthopip int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null
) engine=MyISAM;
create index bgp_vpnv4_dt on bgp_vpnv4_log_0000(dtwhen);
create index bgp_vpnv4_net on bgp_vpnv4_log_0000(kind,netaddrrdh,netaddrrdl,netaddr,netsize);
create index bgp_vpnv4_lbl on bgp_vpnv4_log_0000(bgplabels);
create index bgp_vpnv4_ec on bgp_vpnv4_log_0000(bgpextcom);
create index bgp_vpnv4_cm on bgp_vpnv4_log_0000(bgpcommunities);
create table bgp_vpnv4_log (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 128 - vpnv4u
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 netaddr int unsigned not null default 0, -- network address
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 nexthoprdh int unsigned null,
 nexthoprdl int unsigned null,
 nexthopip int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 KEY `bgp_vpnv4_dt` (`dtwhen`),
 KEY `bgp_vpnv4_net` (`kind`,`netaddrrdh`,`netaddrrdl`,`netaddr`,`netsize`),
 KEY `bgp_vpnv4_lbl` (`bgplabels`),
 KEY `bgp_vpnv4_ec` (`bgpextcom`),
 KEY `bgp_vpnv4_cm` (`bgpcommunities`)
) engine=MRG_MyISAM INSERT_METHOD=LAST UNION=(`bgp_vpnv4_log_0000`);

DROP PROCEDURE IF EXISTS wr_vpnv4;
DELIMITER //
CREATE PROCEDURE wr_vpnv4(IN _srcid INT,IN _state tinyint,IN _kind tinyint unsigned,IN _netaddrrdh int unsigned,IN _netaddrrdl int unsigned,IN _netaddr int unsigned,IN _netsize tinyint unsigned,
IN _bgporigin tinyint unsigned,IN _bgpaspath varchar(255),IN _bgpcommunities varchar(255),
IN _nhrrdh int unsigned,IN _nhrrdl int unsigned,IN _nh int unsigned,IN _bgpmed int unsigned,IN _bgplocalpref int unsigned,
 IN _bgpatomicaggregate int unsigned,IN _bgpaggregatoras int unsigned,IN _bgpagregatorIP int unsigned,IN _bgporiginatorIP int unsigned,IN _bgpextcom varchar(255),
 IN _bgplabels varchar(255)
)
    DETERMINISTIC
    SQL SECURITY DEFINER
BEGIN
 declare state1 tinyint;
 declare bgporigin1 tinyint unsigned;
 declare bgpaspath1 varchar(255);
 declare bgpcommunities1 varchar(255);
 declare nhrrdh1 int unsigned;
 declare nhrrdl1 int unsigned;
 declare nh1 int unsigned;
 declare bgpmed1 int unsigned;
 declare bgplocalpref1 int unsigned;
 declare bgpatomicaggregate1 int unsigned;
 declare bgpaggregatoras1 int unsigned;
 declare bgpagregatorIP1 int unsigned;
 declare bgporiginatorIP1 int unsigned;
 declare bgpextcom1 varchar(255);
 declare bgplabels1 varchar(255);
 select state,bgporigin,bgpaspath,bgpcommunities,nexthoprdh,nexthoprdl,nexthopip,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels
  into state1,bgporigin1,bgpaspath1,bgpcommunities1,nhrrdh1,nhrrdl1,nh1,bgpmed1,bgplocalpref1,bgpatomicaggregate1,bgpaggregatoras1,bgpagregatorIP1,bgporiginatorIP1,bgpextcom1,bgplabels1
   from bgp_vpnv4 where srcid=_srcid and kind=_kind and netaddrrdh=_netaddrrdh and netaddrrdl=_netaddrrdl and  netaddr=_netaddr and netsize=_netsize limit 1;
 if state1=_state and bgporigin1=_bgporigin and coalesce(bgpaspath1,'-')=coalesce(_bgpaspath,'-') and coalesce(bgpcommunities1,'-')=coalesce(_bgpcommunities,'-') and coalesce(nhrrdh1,0)=coalesce(_nhrrdh,0)  and coalesce(nhrrdl1,0)=coalesce(_nhrrdl,0)  and coalesce(nh1,0)=coalesce(_nh,0) and coalesce(bgpmed1,0)=coalesce(_bgpmed,0) and coalesce(bgplocalpref1,0)=coalesce(_bgplocalpref,0) and coalesce(bgpatomicaggregate1,0)=coalesce(_bgpatomicaggregate,0) and coalesce(bgpaggregatoras1,0)=coalesce(_bgpaggregatoras,0) and coalesce(bgpagregatorIP1,0)=coalesce(_bgpagregatorIP,0) and coalesce(bgporiginatorIP1,0)=coalesce(_bgporiginatorIP,0) and coalesce(bgpextcom1,'-')=coalesce(_bgpextcom,'-') then
  set state1=1;
 else
 replace into bgp_vpnv4 (srcid,state,kind,netaddrrdh,netaddrrdl,netaddr,netsize,bgporigin,bgpaspath,bgpcommunities,nexthoprdh,nexthoprdl,nexthopip,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddrrdh,_netaddrrdl,_netaddr,_netsize,_bgporigin,_bgpaspath,_bgpcommunities,_nhrrdh,_nhrrdl,_nh,_bgpmed,_bgplocalpref,_bgpatomicaggregate,_bgpaggregatoras,_bgpagregatorIP,_bgporiginatorIP,_bgpextcom,_bgplabels);
 insert delayed into bgp_vpnv4_log (srcid,state,kind,netaddrrdh,netaddrrdl,netaddr,netsize,bgporigin,bgpaspath,bgpcommunities,nexthoprdh,nexthoprdl,nexthopip,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddrrdh,_netaddrrdl,_netaddr,_netsize,_bgporigin,_bgpaspath,_bgpcommunities,_nhrrdh,_nhrrdl,_nh,_bgpmed,_bgplocalpref,_bgpatomicaggregate,_bgpaggregatoras,_bgpagregatorIP,_bgporiginatorIP,_bgpextcom,_bgplabels);
 commit;
 end if;
END;
//
DELIMITER ;

create table bgp_ipv6 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - ipv6u_nlri ; 2 - ipv6u_withdraw
 kind tinyint unsigned not null default 0,
 netaddrh bigint unsigned not null default 0, -- network address high part
 netaddrl bigint unsigned not null default 0, -- network address low part
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthoph bigint unsigned null, -- nexthop address high part
 bgpnexthopl bigint unsigned null, -- nexthop address low part
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregateh bigint unsigned null, -- aa address
 bgpatomicaggregatel bigint unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIPh bigint unsigned null,
 bgpagregatorIPl bigint unsigned null,
 bgporiginatorIPh bigint unsigned null,
 bgporiginatorIPl bigint unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 primary key (srcid,kind,netaddrh,netaddrl,netsize)
) engine=InnoDB;
create index bgp_ipv6_lbl on bgp_ipv6(bgplabels);
create index bgp_ipv6_ec on bgp_ipv6(bgpextcom);
create index bgp_ipv6_cm on bgp_ipv6(bgpcommunities);

create table bgp_ipv6_log_0000 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - ipv6u_nlri ; 2 - ipv6u_withdraw
 kind tinyint unsigned not null default 0, -- 1 - ipv6u ; 2 - ipv6m ; 4 - ipv6lu
 netaddrh bigint unsigned not null default 0, -- network address high part
 netaddrl bigint unsigned not null default 0, -- network address low part
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthoph bigint unsigned null, -- nexthop address high part
 bgpnexthopl bigint unsigned null, -- nexthop address low part
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregateh bigint unsigned null, -- aa address
 bgpatomicaggregatel bigint unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIPh bigint unsigned null,
 bgpagregatorIPl bigint unsigned null,
 bgporiginatorIPh bigint unsigned null,
 bgporiginatorIPl bigint unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null
) engine=MyISAM;
create index bgp_ipv6_dt on bgp_ipv6_log_0000(dtwhen);
create index bgp_ipv6_net on bgp_ipv6_log_0000(srcid,kind,netaddrh,netaddrl,netsize);
create index bgp_ipv6_lbl on bgp_ipv6_log_0000(bgplabels);
create index bgp_ipv6_ec on bgp_ipv6_log_0000(bgpextcom);
create index bgp_ipv6_cm on bgp_ipv6_log_0000(bgpcommunities);
create table bgp_ipv6_log (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - ipv6u_nlri ; 2 - ipv6u_withdraw
 kind tinyint unsigned not null default 0, -- 1 - ipv6u ; 2 - ipv6m ; 4 - ipv6lu
 netaddrh bigint unsigned not null default 0, -- network address high part
 netaddrl bigint unsigned not null default 0, -- network address low part
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthoph bigint unsigned null, -- nexthop address high part
 bgpnexthopl bigint unsigned null, -- nexthop address low part
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregateh bigint unsigned null, -- aa address
 bgpatomicaggregatel bigint unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIPh bigint unsigned null,
 bgpagregatorIPl bigint unsigned null,
 bgporiginatorIPh bigint unsigned null,
 bgporiginatorIPl bigint unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 KEY `bgp_ipv6_dt` (`dtwhen`),
 KEY `bgp_ipv6_net` (`srcid`,`kind`,`netaddrh`,`netaddrl`,`netsize`),
 KEY `bgp_ipv6_lbl` (`bgplabels`),
 KEY `bgp_ipv6_ec` (`bgpextcom`),
 KEY `bgp_ipv6_cm` (`bgpcommunities`)
) engine=MRG_MyISAM INSERT_METHOD=LAST UNION=(`bgp_ipv6_log_0000`);

DROP PROCEDURE IF EXISTS wr_ipv6;
DELIMITER //
CREATE PROCEDURE wr_ipv6(IN _srcid INT,IN _state tinyint,IN _kind tinyint unsigned,IN _netaddrh bigint unsigned,IN _netaddrl bigint unsigned,IN _netsize tinyint unsigned,IN _bgporigin tinyint unsigned,
 IN _bgpaspath varchar(255),IN _bgpcommunities varchar(255),IN _bgpnexthoph bigint unsigned,IN _bgpnexthopl bigint unsigned,IN _bgpmed int unsigned,IN _bgplocalpref int unsigned,
 IN _bgpatomicaggregateh bigint unsigned,IN _bgpatomicaggregatel bigint unsigned,IN _bgpaggregatoras int unsigned,
 IN _bgpagregatorIPh bigint unsigned,IN _bgpagregatorIPl bigint unsigned,
 IN _bgporiginatorIPh bigint unsigned,IN _bgporiginatorIPl bigint unsigned,IN _bgpextcom varchar(255),
 IN _bgplabels varchar(255)
)
    DETERMINISTIC
    SQL SECURITY DEFINER
BEGIN
 declare state1 tinyint;
 declare bgporigin1 tinyint unsigned;
 declare bgpaspath1 varchar(255);
 declare bgpcommunities1 varchar(255);
 declare bgpnexthoph1 bigint unsigned;
 declare bgpnexthopl1 bigint unsigned;
 declare bgpmed1 int unsigned;
 declare bgplocalpref1 int unsigned;
 declare bgpatomicaggregateh1 bigint unsigned;
 declare bgpatomicaggregatel1 bigint unsigned;
 declare bgpaggregatoras1 int unsigned;
 declare bgpagregatorIPh1 bigint unsigned;
 declare bgpagregatorIPl1 bigint unsigned;
 declare bgporiginatorIPh1 bigint unsigned;
 declare bgporiginatorIPl1 bigint unsigned;
 declare bgpextcom1 varchar(255);
 declare bgplabels1 varchar(255);
 select state,bgporigin,bgpaspath,bgpcommunities,bgpnexthoph,bgpnexthopl,bgpmed,bgplocalpref,bgpatomicaggregateh,bgpatomicaggregatel,bgpaggregatoras,bgpagregatorIPh,bgpagregatorIPl,
  bgporiginatorIPh,bgporiginatorIPl,bgpextcom,bgplabels
  into state1,bgporigin1,bgpaspath1,bgpcommunities1,bgpnexthoph1,bgpnexthopl1,bgpmed1,bgplocalpref1,bgpatomicaggregateh1,bgpatomicaggregatel1,bgpaggregatoras1,bgpagregatorIPh1,bgpagregatorIPl1,
  bgporiginatorIPh1,bgporiginatorIPl1,bgpextcom1,bgplabels1
   from bgp_ipv6 where kind=_kind and srcid=_srcid and netaddrh=_netaddrh and netaddrl=_netaddrl and netsize=_netsize;
 if state1=_state and bgporigin1=_bgporigin and coalesce(bgpaspath1,'-')=coalesce(_bgpaspath,'-') and coalesce(bgpcommunities1,'-')=coalesce(_bgpcommunities,'-') and coalesce(bgpnexthoph1,0)=coalesce(_bgpnexthoph,0) and coalesce(bgpnexthopl1,0)=coalesce(_bgpnexthopl,0) and coalesce(bgpmed1,0)=coalesce(_bgpmed,0) and coalesce(bgplocalpref1,0)=coalesce(_bgplocalpref,0)
  and coalesce(bgpatomicaggregateh1,0)=coalesce(_bgpatomicaggregateh,0) and coalesce(bgpatomicaggregatel1,0)=coalesce(_bgpatomicaggregatel,0) and coalesce(bgpaggregatoras1,0)=coalesce(_bgpaggregatoras,0)
   and coalesce(bgpagregatorIPh1,0)=coalesce(_bgpagregatorIPh,0) and coalesce(bgpagregatorIPl1,0)=coalesce(_bgpagregatorIPl,0) and coalesce(bgporiginatorIPh1,0)=coalesce(_bgporiginatorIPh,0) and coalesce(bgporiginatorIPl1,0)=coalesce(_bgporiginatorIPl,0) 
   and coalesce(bgpextcom1,'-')=coalesce(_bgpextcom,'-') then
  set state1=1;
 else
 replace into bgp_ipv6 (srcid,state,kind,netaddrh,netaddrl,netsize,bgporigin,bgpaspath,bgpcommunities,bgpnexthoph,bgpnexthopl,bgpmed,bgplocalpref,bgpatomicaggregateh,bgpatomicaggregatel,bgpaggregatoras,bgpagregatorIPh,bgpagregatorIPl,bgporiginatorIPh,bgporiginatorIPl,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddrh,_netaddrl,_netsize,_bgporigin,_bgpaspath,_bgpcommunities,_bgpnexthoph,_bgpnexthopl,_bgpmed,_bgplocalpref,_bgpatomicaggregateh,_bgpatomicaggregatel,_bgpaggregatoras,_bgpagregatorIPh,_bgpagregatorIPh,_bgporiginatorIPh,_bgporiginatorIPl,_bgpextcom,_bgplabels);
 insert delayed into bgp_ipv6_log (srcid,state,kind,netaddrh,netaddrl,netsize,bgporigin,bgpaspath,bgpcommunities,bgpnexthoph,bgpnexthopl,bgpmed,bgplocalpref,bgpatomicaggregateh,bgpatomicaggregatel,bgpaggregatoras,bgpagregatorIPh,bgpagregatorIPl,bgporiginatorIPh,bgporiginatorIPl,bgpextcom,bgplabels)
  values (_srcid,_state,_kind,_netaddrh,_netaddrl,_netsize,_bgporigin,_bgpaspath,_bgpcommunities,_bgpnexthoph,_bgpnexthopl,_bgpmed,_bgplocalpref,_bgpatomicaggregateh,_bgpatomicaggregatel,_bgpaggregatoras,_bgpagregatorIPh,_bgpagregatorIPl,_bgporiginatorIPh,_bgporiginatorIPl,_bgpextcom,_bgplabels);
 commit; 
 end if;
END;
//
DELIMITER ;

create table bgp_vpnv6 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 128 - vpnv4u
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 netaddrh bigint unsigned not null default 0, -- network address high part
 netaddrl bigint unsigned not null default 0, -- network address low part
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 nexthoprdh int unsigned null,
 nexthoprdl int unsigned null,
 nexthopiph bigint unsigned null, -- nexthop address
 nexthopipl bigint unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregateh bigint unsigned null, -- aa address
 bgpatomicaggregatel bigint unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIPh bigint unsigned null,
 bgpagregatorIPl bigint unsigned null,
 bgporiginatorIPh bigint unsigned null,
 bgporiginatorIPl bigint unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 primary key (srcid,kind,netaddrrdh,netaddrrdl,netaddrh,netaddrl,netsize)
) engine=InnoDB;
create index bgp_vpnv6_lbl on bgp_vpnv6(bgplabels);
create index bgp_vpnv6_ec on bgp_vpnv6(bgpextcom);
create index bgp_vpnv6_cm on bgp_vpnv6(bgpcommunities);

create table bgp_vpnv6_log_0000 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 128 - vpnv4u
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 netaddrh bigint unsigned not null default 0, -- network address
 netaddrl bigint unsigned not null default 0, -- network address
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 nexthoprdh int unsigned null,
 nexthoprdl int unsigned null,
 nexthopiph bigint unsigned null, -- nexthop address
 nexthopipl bigint unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregateh bigint unsigned null, -- aa address
 bgpatomicaggregatel bigint unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIPh bigint unsigned null,
 bgpagregatorIPl bigint unsigned null,
 bgporiginatorIPh bigint unsigned null,
 bgporiginatorIPl bigint unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null
) engine=MyISAM;
create index bgp_vpnv6_dt on bgp_vpnv6_log_0000(dtwhen);
create index bgp_vpnv6_net on bgp_vpnv6_log_0000(kind,netaddrrdh,netaddrrdl,netaddrh,netaddrl,netsize);
create index bgp_vpnv6_lbl on bgp_vpnv6_log_0000(bgplabels);
create index bgp_vpnv6_ec on bgp_vpnv6_log_0000(bgpextcom);
create index bgp_vpnv6_cm on bgp_vpnv6_log_0000(bgpcommunities);
create table bgp_vpnv6_log (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 128 - vpnv4u
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 netaddrh bigint unsigned not null default 0, -- network address
 netaddrl bigint unsigned not null default 0, -- network address
 netsize tinyint unsigned not null default 0, -- network size
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 nexthoprdh int unsigned null,
 nexthoprdl int unsigned null,
 nexthopiph bigint unsigned null, -- nexthop address
 nexthopipl bigint unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregateh bigint unsigned null, -- aa address
 bgpatomicaggregatel bigint unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIPh bigint unsigned null,
 bgpagregatorIPl bigint unsigned null,
 bgporiginatorIPh bigint unsigned null,
 bgporiginatorIPl bigint unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 KEY `bgp_vpnv6_dt` (`dtwhen`),
 KEY `bgp_vpnv6_net` (`kind`,`netaddrrdh`,`netaddrrdl`,`netaddrh`,`netaddrl`,`netsize`),
 KEY `bgp_vpnv6_lbl` (`bgplabels`),
 KEY `bgp_vpnv6_ec` (`bgpextcom`),
 KEY `bgp_vpnv6_cm` (`bgpcommunities`)
) engine=MRG_MyISAM INSERT_METHOD=LAST UNION=(`bgp_vpnv6_log_0000`);

DROP PROCEDURE IF EXISTS wr_vpnv6;
DELIMITER //
CREATE PROCEDURE wr_vpnv6(IN _srcid INT,IN _state tinyint,IN _kind tinyint unsigned,IN _netaddrrdh int unsigned,IN _netaddrrdl int unsigned,IN _netaddrh bigint unsigned,IN _netaddrl bigint unsigned,IN _netsize tinyint unsigned,
IN _bgporigin tinyint unsigned,IN _bgpaspath varchar(255),IN _bgpcommunities varchar(255),
IN _nhrrdh int unsigned,IN _nhrrdl int unsigned,IN _nhh bigint unsigned,IN _nhl bigint unsigned,IN _bgpmed int unsigned,IN _bgplocalpref int unsigned,
 IN _bgpatomicaggregateh bigint unsigned,IN _bgpatomicaggregatel bigint unsigned,IN _bgpaggregatoras int unsigned,
 IN _bgpagregatorIPh bigint unsigned,IN _bgpagregatorIPl bigint unsigned,IN _bgporiginatorIPh bigint unsigned,IN _bgporiginatorIPl bigint unsigned,IN _bgpextcom varchar(255),
 IN _bgplabels varchar(255)
)
    DETERMINISTIC
    SQL SECURITY DEFINER
BEGIN
 declare state1 tinyint;
 declare bgporigin1 tinyint unsigned;
 declare bgpaspath1 varchar(255);
 declare bgpcommunities1 varchar(255);
 declare nhrrdh1 int unsigned;
 declare nhrrdl1 int unsigned;
 declare nhh1 bigint unsigned;
 declare nhl1 bigint unsigned;
 declare bgpmed1 int unsigned;
 declare bgplocalpref1 int unsigned;
 declare bgpatomicaggregateh1 bigint unsigned;
 declare bgpatomicaggregatel1 bigint unsigned;
 declare bgpaggregatoras1 int unsigned;
 declare bgpagregatorIPh1 bigint unsigned;
 declare bgpagregatorIPl1 bigint unsigned;
 declare bgporiginatorIPh1 bigint unsigned;
 declare bgporiginatorIPl1 bigint unsigned;
 declare bgpextcom1 varchar(255);
 declare bgplabels1 varchar(255);
 select state,bgporigin,bgpaspath,bgpcommunities,nexthoprdh,nexthoprdl,nexthopiph,nexthopipl,bgpmed,bgplocalpref,bgpatomicaggregateh,bgpatomicaggregatel,bgpaggregatoras,bgpagregatorIPh,bgpagregatorIPl,bgporiginatorIPh,bgporiginatorIPl,bgpextcom,bgplabels
  into state1,bgporigin1,bgpaspath1,bgpcommunities1,nhrrdh1,nhrrdl1,nhh1,nhl1,bgpmed1,bgplocalpref1,bgpatomicaggregateh1,bgpatomicaggregatel1,bgpaggregatoras1,bgpagregatorIPh1,bgpagregatorIPl1,bgporiginatorIPh1,bgporiginatorIPl1,bgpextcom1,bgplabels1
   from bgp_vpnv6 where srcid=_srcid and kind=_kind and netaddrrdh=_netaddrrdh and netaddrrdl=_netaddrrdl and  netaddrh=_netaddrh and  netaddrl=_netaddrl and netsize=_netsize limit 1;
 if state1=_state and bgporigin1=_bgporigin and coalesce(bgpaspath1,'-')=coalesce(_bgpaspath,'-') and coalesce(bgpcommunities1,'-')=coalesce(_bgpcommunities,'-') and coalesce(nhrrdh1,0)=coalesce(_nhrrdh,0)  and coalesce(nhrrdl1,0)=coalesce(_nhrrdl,0)  and coalesce(nhh1,0)=coalesce(_nhh,0)  and coalesce(nhl1,0)=coalesce(_nhl,0) and coalesce(bgpmed1,0)=coalesce(_bgpmed,0) and coalesce(bgplocalpref1,0)=coalesce(_bgplocalpref,0)
  and coalesce(bgpatomicaggregateh1,0)=coalesce(_bgpatomicaggregateh,0) and coalesce(bgpatomicaggregatel1,0)=coalesce(_bgpatomicaggregatel,0) and coalesce(bgpaggregatoras1,0)=coalesce(_bgpaggregatoras,0)
   and coalesce(bgpagregatorIPh1,0)=coalesce(_bgpagregatorIPh,0) and coalesce(bgpagregatorIPl1,0)=coalesce(_bgpagregatorIPl,0)
    and coalesce(bgporiginatorIPh1,0)=coalesce(_bgporiginatorIPh,0)  and coalesce(bgporiginatorIPl1,0)=coalesce(_bgporiginatorIPl,0) and coalesce(bgpextcom1,'-')=coalesce(_bgpextcom,'-') then
  set state1=1;
 else
 replace into bgp_vpnv6 (srcid,state,kind,netaddrrdh,netaddrrdl,netaddrh,netaddrl,netsize,bgporigin,bgpaspath,bgpcommunities,nexthoprdh,nexthoprdl,nexthopiph,nexthopipl,bgpmed,bgplocalpref,bgpatomicaggregateh,bgpatomicaggregatel,bgpaggregatoras,bgpagregatorIPh,bgpagregatorIPh,bgporiginatorIPh,bgporiginatorIPl,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddrrdh,_netaddrrdl,_netaddrh,_netaddrl,_netsize,_bgporigin,_bgpaspath,_bgpcommunities,_nhrrdh,_nhrrdl,_nhh,_nhl,_bgpmed,_bgplocalpref,_bgpatomicaggregateh,_bgpatomicaggregatel,_bgpaggregatoras,_bgpagregatorIPh,_bgpagregatorIPl,_bgporiginatorIPh,_bgporiginatorIPl,_bgpextcom,_bgplabels);
 insert delayed into bgp_vpnv6_log (srcid,state,kind,netaddrrdh,netaddrrdl,netaddrh,netaddrl,netsize,bgporigin,bgpaspath,bgpcommunities,nexthoprdh,nexthoprdl,nexthopiph,nexthopipl,bgpmed,bgplocalpref,bgpatomicaggregateh,bgpatomicaggregatel,bgpaggregatoras,bgpagregatorIPh,bgpagregatorIPh,bgporiginatorIPh,bgporiginatorIPl,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddrrdh,_netaddrrdl,_netaddrh,_netaddrl,_netsize,_bgporigin,_bgpaspath,_bgpcommunities,_nhrrdh,_nhrrdl,_nhh,_nhl,_bgpmed,_bgplocalpref,_bgpatomicaggregateh,_bgpatomicaggregatel,_bgpaggregatoras,_bgpagregatorIPh,_bgpagregatorIPl,_bgporiginatorIPh,_bgporiginatorIPl,_bgpextcom,_bgplabels);
 commit;
 end if;
END;
//
DELIMITER ;

create table bgp_l2vpn (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 65 - l2vpn
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 site int unsigned not null default 0,
 offset int unsigned not null default 0,
 srange int unsigned not null default 0,
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthop int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 primary key (srcid,kind,netaddrrdh,netaddrrdl,site,offset,srange)
) engine=InnoDB;
create index bgp_l2vpn_lbl on bgp_l2vpn(bgplabels);
create index bgp_l2vpn_ec on bgp_l2vpn(bgpextcom);
create index bgp_l2vpn_cm on bgp_l2vpn(bgpcommunities);

create table bgp_l2vpn_log_0000 (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 65 - l2vpn
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 site int unsigned not null default 0,
 offset int unsigned not null default 0,
 srange int unsigned not null default 0,
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthop int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null
) engine=MyISAM;
create index bgp_l2vpn_dt on bgp_l2vpn_log_0000(dtwhen);
create index bgp_l2vpn_net on bgp_l2vpn_log_0000(srcid,kind,netaddrrdh,netaddrrdl,site,offset,srange);
create index bgp_l2vpn_lbl on bgp_l2vpn_log_0000(bgplabels);
create index bgp_l2vpn_ec on bgp_l2vpn_log_0000(bgpextcom);
create index bgp_l2vpn_cm on bgp_l2vpn_log_0000(bgpcommunities);
create table bgp_l2vpn_log (
 srcid int not null references bgp_src(id),
 dtwhen timestamp not null default CURRENT_TIMESTAMP,
 state tinyint not null default 0, -- 1 - nlri ; 2 - withdraw
 kind tinyint unsigned not null default 0, -- 65 - l2vpn
 netaddrrdh int unsigned not null default 0, -- network address RD high
 netaddrrdl int unsigned not null default 0, -- network address RD low
 site int unsigned not null default 0,
 offset int unsigned not null default 0,
 srange int unsigned not null default 0,
 bgporigin tinyint unsigned not null default 0, -- bgp origin code
 bgpaspath varchar(255) null, -- bgp aspath
 bgpcommunities varchar(255) null,
 bgpnexthop int unsigned null, -- nexthop address
 bgpmed int unsigned null,
 bgplocalpref int unsigned null,
 bgpatomicaggregate int unsigned null, -- aa address
 bgpaggregatoras int unsigned null,
 bgpagregatorIP int unsigned null,
 bgporiginatorIP int unsigned null,
 bgpextcom varchar(255) null,
 bgplabels varchar(255) null,
 KEY `bgp_l2vpn_dt` (`dtwhen`),
 KEY `bgp_l2vpn_net` (`srcid`,`kind`,`netaddrrdh`,`netaddrrdl`,`site`,`offset`,`srange`),
 KEY `bgp_l2vpn_lbl` (`bgplabels`),
 KEY `bgp_l2vpn_ec` (`bgpextcom`),
 KEY `bgp_l2vpn_cm` (`bgpcommunities`)
) engine=MRG_MyISAM INSERT_METHOD=LAST UNION=(`bgp_l2vpn_log_0000`);

DROP PROCEDURE IF EXISTS wr_l2vpn;
DELIMITER //
CREATE PROCEDURE wr_l2vpn(IN _srcid INT,IN _state tinyint,IN _kind tinyint unsigned,IN _netaddrrdh int unsigned,IN _netaddrrdl int unsigned,IN _site smallint unsigned,IN _offset smallint unsigned,IN _srange smallint unsigned,
IN _bgporigin tinyint unsigned,IN _bgpaspath varchar(255),IN _bgpcommunities varchar(255),
IN _nh int unsigned,IN _bgpmed int unsigned,IN _bgplocalpref int unsigned,
 IN _bgpatomicaggregate int unsigned,IN _bgpaggregatoras int unsigned,IN _bgpagregatorIP int unsigned,IN _bgporiginatorIP int unsigned,IN _bgpextcom varchar(255),
 IN _bgplabels varchar(255)
)
    DETERMINISTIC
    SQL SECURITY DEFINER
BEGIN
 declare state1 tinyint;
 declare bgporigin1 tinyint unsigned;
 declare bgpaspath1 varchar(255);
 declare bgpcommunities1 varchar(255);
 declare site1 smallint unsigned;
 declare offset1 smallint unsigned;
 declare srange1 smallint unsigned;
 declare nh1 int unsigned;
 declare bgpmed1 int unsigned;
 declare bgplocalpref1 int unsigned;
 declare bgpatomicaggregate1 int unsigned;
 declare bgpaggregatoras1 int unsigned;
 declare bgpagregatorIP1 int unsigned;
 declare bgporiginatorIP1 int unsigned;
 declare bgpextcom1 varchar(255);
 declare bgplabels1 varchar(255);
 select state,bgporigin,bgpaspath,bgpcommunities,bgpnexthop,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels
  into state1,bgporigin1,bgpaspath1,bgpcommunities1,nh1,bgpmed1,bgplocalpref1,bgpatomicaggregate1,bgpaggregatoras1,bgpagregatorIP1,bgporiginatorIP1,bgpextcom1,bgplabels1
   from bgp_l2vpn where srcid=_srcid and kind=_kind and netaddrrdh=_netaddrrdh and netaddrrdl=_netaddrrdl and site=_site and offset=_offset and srange=_srange limit 1;
 if state1=_state and bgporigin1=_bgporigin and coalesce(bgpaspath1,'-')=coalesce(_bgpaspath,'-') and coalesce(bgpcommunities1,'-')=coalesce(_bgpcommunities,'-') and coalesce(nh1,0)=coalesce(_nh,0) and coalesce(bgpmed1,0)=coalesce(_bgpmed,0) and coalesce(bgplocalpref1,0)=coalesce(_bgplocalpref,0) and coalesce(bgpatomicaggregate1,0)=coalesce(_bgpatomicaggregate,0) and coalesce(bgpaggregatoras1,0)=coalesce(_bgpaggregatoras,0) and coalesce(bgpagregatorIP1,0)=coalesce(_bgpagregatorIP,0) and coalesce(bgporiginatorIP1,0)=coalesce(_bgporiginatorIP,0) and coalesce(bgpextcom1,'-')=coalesce(_bgpextcom,'-') then
  set state1=1;
 else
 replace into bgp_l2vpn (srcid,state,kind,netaddrrdh,netaddrrdl,site,offset,srange,bgporigin,bgpaspath,bgpcommunities,bgpnexthop,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddrrdh,_netaddrrdl,_site,_offset,_srange,_bgporigin,_bgpaspath,_bgpcommunities,_nh,_bgpmed,_bgplocalpref,_bgpatomicaggregate,_bgpaggregatoras,_bgpagregatorIP,_bgporiginatorIP,_bgpextcom,_bgplabels);
 insert delayed into bgp_l2vpn_log (srcid,state,kind,netaddrrdh,netaddrrdl,site,offset,srange,bgporigin,bgpaspath,bgpcommunities,bgpnexthop,bgpmed,bgplocalpref,bgpatomicaggregate,bgpaggregatoras,bgpagregatorIP,bgporiginatorIP,bgpextcom,bgplabels) values (_srcid,_state,_kind,_netaddrrdh,_netaddrrdl,_site,_offset,_srange,_bgporigin,_bgpaspath,_bgpcommunities,_nh,_bgpmed,_bgplocalpref,_bgpatomicaggregate,_bgpaggregatoras,_bgpagregatorIP,_bgporiginatorIP,_bgpextcom,_bgplabels);
 commit;
 end if;
END;
//
DELIMITER ;
